## Generic

Package `datamaestro.data`

::xpm::datamaestro.data:Base
::xpm::datamaestro.data:Generic
::xpm::datamaestro.data:File


## CSV data

Package `datamaestro.data.csv`

::xpm::datamaestro.data.csv:Generic
::xpm::datamaestro.data.csv:Matrix

## Machine Learning

Package `datamaestro.data.ml`

::xpm::datamaestro.data.ml:Supervised
::xpm::datamaestro.data.ml:FolderBased

## Tensor

Package `datamaestro.data.tensor`

::xpm::datamaestro.data.tensor:IDX
